OpCode

Struct OpCode 

#[repr(transparent)]
pub struct OpCode { pub repr: i32, }

Fields

repr: i32

Implementations

Source

impl OpCode

pub const CPUI_COPY: Self

Copy one operand to another

pub const CPUI_LOAD: Self

Load from a pointer into a specified address space

pub const CPUI_STORE: Self

Store at a pointer into a specified address space

pub const CPUI_BRANCH: Self

Always branch

pub const CPUI_CBRANCH: Self

Conditional branch

pub const CPUI_BRANCHIND: Self

Indirect branch (jumptable)

pub const CPUI_CALL: Self

Call to an absolute address

pub const CPUI_CALLIND: Self

Call through an indirect address

pub const CPUI_CALLOTHER: Self

User-defined operation

pub const CPUI_RETURN: Self

Return from subroutine

pub const CPUI_INT_EQUAL: Self

Integer comparison, equality (==)

pub const CPUI_INT_NOTEQUAL: Self

Integer comparison, in-equality (!=)

pub const CPUI_INT_SLESS: Self

Integer comparison, signed less-than (<)

pub const CPUI_INT_SLESSEQUAL: Self

Integer comparison, signed less-than-or-equal (<=)

pub const CPUI_INT_LESS: Self

Integer comparison, unsigned less-than (<) This also indicates a borrow on unsigned substraction

pub const CPUI_INT_LESSEQUAL: Self

Integer comparison, unsigned less-than-or-equal (<=)

pub const CPUI_INT_ZEXT: Self

Zero extension

pub const CPUI_INT_SEXT: Self

Sign extension

pub const CPUI_INT_ADD: Self

Addition, signed or unsigned (+)

pub const CPUI_INT_SUB: Self

Subtraction, signed or unsigned (-)

pub const CPUI_INT_CARRY: Self

Test for unsigned carry

pub const CPUI_INT_SCARRY: Self

Test for signed carry

pub const CPUI_INT_SBORROW: Self

Test for signed borrow

pub const CPUI_INT_2COMP: Self

Twos complement

pub const CPUI_INT_NEGATE: Self

Logical/bitwise negation (~)

pub const CPUI_INT_XOR: Self

Logical/bitwise exclusive-or (^)

pub const CPUI_INT_AND: Self

Logical/bitwise and (&)

pub const CPUI_INT_OR: Self

Logical/bitwise or (|)

pub const CPUI_INT_LEFT: Self

Left shift (<<)

pub const CPUI_INT_RIGHT: Self

Right shift, logical (>>)

pub const CPUI_INT_SRIGHT: Self

Right shift, arithmetic (>>)

pub const CPUI_INT_MULT: Self

Integer multiplication, signed and unsigned (*)

pub const CPUI_INT_DIV: Self

Integer division, unsigned (/)

pub const CPUI_INT_SDIV: Self

Integer division, signed (/)

pub const CPUI_INT_REM: Self

Remainder/modulo, unsigned (%)

pub const CPUI_INT_SREM: Self

Remainder/modulo, signed (%)

pub const CPUI_BOOL_NEGATE: Self

Boolean negate (!)

pub const CPUI_BOOL_XOR: Self

Boolean exclusive-or (^^)

pub const CPUI_BOOL_AND: Self

Boolean and (&&)

pub const CPUI_BOOL_OR: Self

Boolean or (||)

pub const CPUI_FLOAT_EQUAL: Self

Floating-point comparison, equality (==)

pub const CPUI_FLOAT_NOTEQUAL: Self

Floating-point comparison, in-equality (!=)

pub const CPUI_FLOAT_LESS: Self

Floating-point comparison, less-than (<)

pub const CPUI_FLOAT_LESSEQUAL: Self

Floating-point comparison, less-than-or-equal (<=)

pub const CPUI_FLOAT_NAN: Self

Not-a-number test (NaN)

pub const CPUI_FLOAT_ADD: Self

Floating-point addition (+)

pub const CPUI_FLOAT_DIV: Self

Floating-point division (/)

pub const CPUI_FLOAT_MULT: Self

Floating-point multiplication (*)

pub const CPUI_FLOAT_SUB: Self

Floating-point subtraction (-)

pub const CPUI_FLOAT_NEG: Self

Floating-point negation (-)

pub const CPUI_FLOAT_ABS: Self

Floating-point absolute value (abs)

pub const CPUI_FLOAT_SQRT: Self

Floating-point square root (sqrt)

pub const CPUI_FLOAT_INT2FLOAT: Self

Convert an integer to a floating-point

pub const CPUI_FLOAT_FLOAT2FLOAT: Self

Convert between different floating-point sizes

pub const CPUI_FLOAT_TRUNC: Self

Round towards zero

pub const CPUI_FLOAT_CEIL: Self

Round towards +infinity

pub const CPUI_FLOAT_FLOOR: Self

Round towards -infinity

pub const CPUI_FLOAT_ROUND: Self

Round towards nearest

pub const CPUI_MULTIEQUAL: Self

Phi-node operator

pub const CPUI_INDIRECT: Self

Copy with an indirect effect

pub const CPUI_PIECE: Self

Concatenate

pub const CPUI_SUBPIECE: Self

Truncate

pub const CPUI_CAST: Self

Cast from one data-type to another

pub const CPUI_PTRADD: Self

Index into an array ([])

pub const CPUI_PTRSUB: Self

Drill down to a sub-field (->)

pub const CPUI_SEGMENTOP: Self

Look-up a \e segmented address

pub const CPUI_CPOOLREF: Self

Recover a value from the \e constant \e pool

pub const CPUI_NEW: Self

Allocate a new object (new)

pub const CPUI_INSERT: Self

Insert a bit-range

pub const CPUI_EXTRACT: Self

Extract a bit-range

pub const CPUI_POPCOUNT: Self

Count the 1-bits

pub const CPUI_LZCOUNT: Self

Count the leading 0-bits

pub const CPUI_MAX: Self

Value indicating the end of the op-code values